/* types of bar sign */
#define SINGLE_BAR 0
#define DOUBLE_BAR 1
#define BAR_REP 2
#define REP_BAR 3
#define BAR1 4
#define REP_BAR2 5
#define DOUBLE_REP 6
#define THICK_THIN 7
#define THIN_THICK 8

/* other things */
#define PART 9
#define TEMPO 10
#define TIME 11
#define KEY 12
#define REST 13
#define TUPLE 14
/* CHORD replaced by CHORDON and CHORDOFF */
#define NOTE 16
#define NONOTE 17
#define TEXT 18
#define SLUR_ON 19
#define SLUR_OFF 20
#define TIE 21
#define TITLE 22
#define PROGRAM 23
#define CHANNEL 24
#define TRANSPOSE 25
#define GRACEON 26
#define GRACEOFF 27
#define SETGRACE 28
#define SETC 29
#define GCHORD 30
#define GCHORDON 31
#define GCHORDOFF 32
#define VOICE 33
#define CHORDON 34
#define CHORDOFF 35
#define SLUR_TIE 36
#define NEWLINE 37
#define TNOTE 38

/* broken rhythm */
#define LT 39
#define GT 40

#define DYNAMIC 41
#define LINENUM 42

/* note decorations */
#define DECSIZE 8
static char decorations[] = ".H~RuvML";
#define STACCATO 0
#define FERMATA 1
#define ORNAMENT 2
#define ROLL 3
#define BOWUP 4
#define BOWDOWN 5
#define TENUTO 6
#define LOUD 7

struct vstring {
int len;
int limit;
char* st;
};

